@@ -44,12 +44,12 @@ public:
     void setOpenDestinationFolderAfterExtraction(bool);
     void setAutoSubfolder(bool value);
 
-    bool extractAllFiles();
-    bool openDestinationAfterExtraction();
-    bool extractToSubfolder();
-    bool autoSubfolders();
-    bool preservePaths();
-    KUrl destinationDirectory();
+    bool extractAllFiles() const;
+    bool openDestinationAfterExtraction() const;
+    bool extractToSubfolder() const;
+    bool autoSubfolders() const;
+    bool preservePaths() const;
+    KUrl destinationDirectory() const;
     QString subfolder() const;
     virtual void accept();
 
@@ -57,9 +57,13 @@ public Q_SLOTS:
     void setCurrentUrl(const QString& url);
     void setSubfolder(QString subfolder);
 
-private:
-    class ExtractionDialogUI *m_ui;
+private Q_SLOTS:
+    void writeSettings();
 
+private:
+    void loadSettings();
+
+    class ExtractionDialogUI *m_ui;
 };
 }
 
