@@ -1,4 +1,4 @@
-// -*- indent-tabs-mode: t -*-
+// -*- indent-tabs-mode: nil -*-
 /*
     kCalculator, a simple scientific calculator for KDE
 
@@ -124,16 +124,15 @@ KCalculator::KCalculator(QWidget *parent)
 
 	// misc setup
 
-	set_colors();
+	setColors();
+	setFonts();
 
 	// Show the result in the app's caption in taskbar (wishlist - bug #52858)
 	if (KCalcSettings::captionResult() == true)
 		connect(calc_display, SIGNAL(changedText(const QString &)),
 				SLOT(setCaption(const QString &)));
 	calc_display->changeSettings();
-	set_precision();
-
-	resetBase(); // switch to decimal
+	setPrecision();
 
 	updateGeometry();
 
@@ -158,10 +157,15 @@ KCalculator::KCalculator(QWidget *parent)
 	actionBitsetshow->setChecked(KCalcSettings::showBitset());
 	slotBitsetshow(KCalcSettings::showBitset());
 
+        setAngle();
+        setBase();
+
 	// connections
 
 	connect(KGlobalSettings::self(), SIGNAL(kdisplayPaletteChanged()),
-			SLOT(set_colors()));
+			SLOT(setColors()));
+	connect(KGlobalSettings::self(), SIGNAL(kdisplayFontChanged()),
+			SLOT(setFonts()));
 
 	calc_display->setFocus();
 }
@@ -733,39 +737,41 @@ void KCalculator::setupKeys()
 
 void KCalculator::updateGeometry(void)
 {
-    QWidget *widget;
+    KCalcButton *button;
     QSize em = pbAND->fontMetrics().size(0, "M");
     int margin =
-		QApplication::style()->pixelMetric(QStyle::PM_ButtonMargin, 0, 0);
+        QApplication::style()->pixelMetric(QStyle::PM_ButtonMargin, 0, 0);
     margin = qMax(qMin(margin/2, 3), 3);
 
-	// left pad
+    // left pad
 
-	foreach (QObject *obj, leftPad->children()) {
-        if ( obj->isWidgetType() ) {
-            widget = static_cast<QWidget*>(obj);
-            widget->setFixedWidth(em.width()*4 + margin*2);
-            widget->installEventFilter( this );
+    foreach (QObject *obj, leftPad->children()) {
+        button = qobject_cast<KCalcButton*>(obj);
+        if ( button ) {
+            button->setFixedWidth(em.width()*4 + margin*2);
+            button->installEventFilter( this );
         }
     }
 
-	// right pad
+    // right pad
 
-	foreach (QObject *obj, rightPad->children()) {
-        if (obj->isWidgetType()) {
-            widget = static_cast<QWidget*>(obj);
-            widget->setFixedWidth(em.width()*3 + margin*2);
-            widget->installEventFilter(this);
+    foreach (QObject *obj, rightPad->children()) {
+        button = qobject_cast<KCalcButton*>(obj);
+        if ( button ) {
+            button->setFixedWidth(em.width()*3 + margin*2);
+            button->installEventFilter(this);
         }
     }
 
-	foreach (QObject *obj, numericPad->children()) {
-        if (obj->isWidgetType()) {
-            widget = static_cast<QWidget *>(obj);
-			if (widget != pb0) { // let pb0 expand freely
-				widget->setFixedWidth(em.width()*3 + margin*2);
-			}
-            widget->installEventFilter(this);
+    // numeric pad
+
+    foreach (QObject *obj, numericPad->children()) {
+        button = qobject_cast<KCalcButton*>(obj);
+        if ( button ) {
+	    if (button != pb0) { // let pb0 expand freely
+		button->setFixedWidth(em.width()*3 + margin*2);
+	    }
+            button->installEventFilter(this);
         }
     }
 }
@@ -832,6 +838,7 @@ void KCalculator::slotBaseSelected(int base)
 			btn->setEnabled(true);
 		}
 	}
+        KCalcSettings::setBaseMode(base);
 }
 
 void KCalculator::keyPressEvent(QKeyEvent *e)
@@ -875,6 +882,7 @@ void KCalculator::slotAngleSelected(int mode)
 	default: // we shouldn't ever end up here
 		_angle_mode = RadMode;
 	}
+        KCalcSettings::setAngleMode(_angle_mode);
 }
 
 void KCalculator::slotEEclicked(void)
@@ -1521,7 +1529,7 @@ void KCalculator::showSettings()
 		SLOT(slotChooseScientificConst5(science_constant const &)));
 	constants->pushButton5->setMenu(tmp_menu);
 
-	dialog->addPage(constants, i18n("Constants"), "preferences-kcalc-constants", i18n("Define constants"));
+	dialog->addPage(constants, i18n("Constants"), "preferences-kcalc-constants", i18n("Define Constants"));
 
 	// When the user clicks OK or Apply we want to update our settings.
 	connect(dialog, SIGNAL(settingsChanged(const QString &)), SLOT(updateSettings()));
@@ -1603,10 +1611,8 @@ void KCalculator::slotScientificshow(bool toggled)
 		foreach (QAbstractButton* btn, AngleChooseGroup->buttons()) {
 			btn->show();
 		}
-		statusBar()->changeItem(" DEG ", AngleField);
 		statusBar()->setItemFixed(AngleField, -1);
-		calc_display->setStatusText(AngleField, "Deg");
-		degRadio->setChecked(true);
+		setAngle();
 	}
 	else
 	{
@@ -1635,13 +1641,12 @@ void KCalculator::slotLogicshow(bool toggled)
 		foreach (QAbstractButton* btn, logicButtons) {
 			btn->show();
 		}
-		statusBar()->changeItem(" HEX ", BaseField);
 		statusBar()->setItemFixed(BaseField, -1);
-		calc_display->setStatusText(BaseField, "Hex");
+                setBase();
+
 		foreach (QAbstractButton *btn, BaseChooseGroup->buttons()) {
 			btn->show();
 		}
-		resetBase();
 		for (int i=10; i<16; i++)
 			(NumButtonGroup->button(i))->show();
 	}
@@ -1656,7 +1661,7 @@ void KCalculator::slotLogicshow(bool toggled)
 			btn->hide();
 		}
 		// Hide Hex-Buttons, but first switch back to decimal
-		resetBase();
+		decRadio->animateClick(0);
 		foreach (QAbstractButton *btn, BaseChooseGroup->buttons()) {
 			btn->hide();
 		}
@@ -1739,8 +1744,9 @@ void KCalculator::slotUpdateBitset(const KNumber &nr)
 void KCalculator::updateSettings()
 {
 	changeButtonNames();
-	set_colors();
-	set_precision();
+	setColors();
+	setFonts();
+	setPrecision();
 	// Show the result in the app's caption in taskbar (wishlist - bug #52858)
 	disconnect(calc_display, SIGNAL(changedText(const QString &)),
 		   this, 0);
@@ -1775,7 +1781,7 @@ void KCalculator::updateDisplay(bool get_amount_from_core,
 
 }
 
-void KCalculator::set_colors()
+void KCalculator::setColors()
 {
 	calc_display->changeSettings();
 
@@ -1818,12 +1824,50 @@ void KCalculator::set_colors()
 	}
 }
 
-void KCalculator::set_precision()
+void KCalculator::setFonts()
+{
+    KCalcButton *button;
+    foreach (QObject *obj, leftPad->children()) {
+	button = qobject_cast<KCalcButton*>(obj);
+        if (button) {
+            button->setFont(KCalcSettings::buttonFont());
+        }
+    }
+    foreach (QObject *obj, numericPad->children()) {
+	button = qobject_cast<KCalcButton*>(obj);
+        if (button) {
+            button->setFont(KCalcSettings::buttonFont());
+        }
+    }
+    foreach (QObject *obj, rightPad->children()) {
+	button = qobject_cast<KCalcButton*>(obj);
+        if (button) {
+            button->setFont(KCalcSettings::buttonFont());
+        }
+    }
+    updateGeometry();
+}
+
+void KCalculator::setPrecision()
 {
 	KNumber:: setDefaultFloatPrecision(KCalcSettings::precision());
 	updateDisplay(false);
 }
 
+void KCalculator::setAngle()
+{
+    QAbstractButton *btn;
+    btn = AngleChooseGroup->button(KCalcSettings::angleMode());
+    if (btn) btn->animateClick(0);
+}
+
+void KCalculator::setBase()
+{
+    QAbstractButton *btn;
+    btn = BaseChooseGroup->button(KCalcSettings::baseMode());
+    if (btn) btn->animateClick(0);
+}
+
 bool KCalculator::eventFilter(QObject *o, QEvent *e)
 {
 	switch(e->type())
