@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: kdessh.cpp 986418 2009-06-24 16:22:23Z kossebau $
+ * $Id: kdessh.cpp 1063316 2009-12-17 20:08:12Z kossebau $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -110,7 +110,7 @@ int main(int argc, char *argv[])
 
     // Get remote userid
     QByteArray user = args->getOption("u").toLocal8Bit();
-    if (user.isNull())
+    if (user.isEmpty())
     {
 	struct passwd *pw = getpwuid(getuid());
 	if (pw == 0L)
