@@ -329,7 +329,7 @@ QGroupBox* KgpgKeyInfo::_photoGroup(QWidget *parent)
     m_photo->setLineWidth(2);
     m_photo->setAlignment(Qt::AlignCenter);
     m_photo->setFrameShape(QFrame::Box);
-    m_photo->setWhatsThis("<qt><b>Photo:</b><p>A photo can be included with a public key for extra security. The photo can be used as an additional method of authenticating the key. However, it should not be relied upon as the only form of authentication.</p></qt>");
+    m_photo->setWhatsThis(i18n("<qt><b>Photo:</b><p>A photo can be included with a public key for extra security. The photo can be used as an additional method of authenticating the key. However, it should not be relied upon as the only form of authentication.</p></qt>"));
 
     QVBoxLayout *layout = new QVBoxLayout(group);
     layout->setMargin(marginHint());
@@ -426,13 +426,13 @@ void KgpgKeyInfo::displayKey()
 
     m_id->setText(m_key->fullId());
     m_algorithm->setText(Convert::toString(m_key->algorithm()) + " / " + Convert::toString(m_key->encryptionAlgorithm()));
-    m_algorithm->setWhatsThis("<qt>The left part is the algorithm used by the <b>signature</b> key. The right part is the algorithm used by the <b>encryption</b> key.</qt>");
+    m_algorithm->setWhatsThis(i18n("<qt>The left part is the algorithm used by the <b>signature</b> key. The right part is the algorithm used by the <b>encryption</b> key.</qt>"));
     m_creation->setText(m_key->creation());
     m_expiration->setText(m_key->expiration());
     m_trust->setText(tr);
     m_trust->setColor(trustcolor);
     m_length->setText(QString::number(m_key->size()) + " / " + QString::number(m_key->encryptionSize()));
-    m_length->setWhatsThis("<qt>The left part is the size of the <b>signature</b> key. The right part is the size of the <b>encryption</b> key.</qt>");
+    m_length->setWhatsThis(i18n("<qt>The left part is the size of the <b>signature</b> key. The right part is the size of the <b>encryption</b> key.</qt>"));
     m_fingerprint->setText(m_key->fingerprintBeautified());
 
     if (m_key->comment().isEmpty())
@@ -540,13 +540,22 @@ void KgpgKeyInfo::slotChangePass()
 	QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
 }
 
-void KgpgKeyInfo::slotInfoPasswordChanged(const int &res)
+void KgpgKeyInfo::slotInfoPasswordChanged(int result)
 {
-    if (res == 2)
-        KPassivePopup::message(i18n("Passphrase for the key was changed"), QString(), Images::kgpg(), this);
-    else if (res == 1)
-        KMessageBox::error(this, i18n("Bad old passphrase, the passphrase for the key was not changed"), i18n("Could not change passphrase"));
-    QApplication::restoreOverrideCursor();
+	switch (result) {
+	case KGpgTransaction::TS_OK:
+		KPassivePopup::message(i18n("Passphrase for the key was changed"), QString(), Images::kgpg(), this);
+		break;
+	case KGpgTransaction::TS_BAD_PASSPHRASE:
+		KMessageBox::error(this, i18n("Bad old passphrase, the passphrase for the key was not changed"), i18n("Could not change passphrase"));
+		break;
+	case KGpgTransaction::TS_USER_ABORTED:
+		break;
+	default:
+		KMessageBox::error(this, i18n("KGpg was unable to change the passphrase.<br />Please see the detailed log for more information."));
+	}
+
+	QApplication::restoreOverrideCursor();
 }
 
 void KgpgKeyInfo::slotChangeTrust(const int &newtrust)
