@@ -30,6 +30,7 @@
 #include "keylistproxymodel.h"
 #include "kgpgitemnode.h"
 #include "kgpginterface.h"
+#include "kgpgimport.h"
 
 KeyTreeView::KeyTreeView(QWidget *parent, KeyListProxyModel *model)
 	: QTreeView(parent), m_proxy(model)
@@ -104,14 +105,32 @@ KeyTreeView::selectNode(KGpgNode *nd)
 void
 KeyTreeView::restoreLayout(KConfigGroup &cg)
 {
-	QStringList cols = cg.readEntry("ColumnWidths", QStringList());
+	QStringList cols(cg.readEntry("ColumnWidths", QStringList()));
 	int i = 0;
 
-	QStringList::ConstIterator it = cols.constBegin();
-	const QStringList::ConstIterator itEnd = cols.constEnd();
+	QStringList::ConstIterator it(cols.constBegin());
+	const QStringList::ConstIterator itEnd(cols.constEnd());
 	for (; it != itEnd; ++it)
 		setColumnWidth(i++, (*it).toInt());
 
+	while (i < model()->columnCount(QModelIndex())) {
+		int width = 100;
+		switch (i) {
+		case KEYCOLUMN_NAME:
+			width = 250;
+			break;
+		case KEYCOLUMN_EMAIL:
+			width = 150;
+			break;
+		case KEYCOLUMN_TRUST:
+			// the trust column needs to be only that big as the header which is done automatically
+			i++;
+			continue;
+		}
+		setColumnWidth(i, width);
+		i++;
+	}
+
 	if (cg.hasKey("SortColumn")) {
 		Qt::SortOrder order = cg.readEntry("SortAscending", true) ? Qt::AscendingOrder : Qt::DescendingOrder;
 		sortByColumn(cg.readEntry("SortColumn", 0), order);
@@ -149,20 +168,10 @@ KeyTreeView::contentsDropEvent(QDropEvent *o)
 					KGuiItem(i18n("Do Not Import"))) != KMessageBox::Yes)
 			return;
 
-		KgpgInterface *interface = new KgpgInterface();
-		connect(interface, SIGNAL(importKeyFinished(KgpgInterface *, QStringList)), SLOT(slotRefreshKeys(KgpgInterface *, QStringList)));
-		interface->importKey(uriList.first());
+		emit importDrop(uriList);
 	}
 }
 
-void
-KeyTreeView::slotRefreshKeys(KgpgInterface *iface, const QStringList &keys)
-{
-	iface->deleteLater();
-	if (!keys.isEmpty())
-		m_proxy->getModel()->refreshKeys(keys);
-}
-
 void
 KeyTreeView::startDrag(Qt::DropActions supportedActions)
 {
@@ -195,3 +204,5 @@ KeyTreeView::resizeColumnsToContents()
 	for (int i = m_proxy->columnCount() - 1; i >= 0; i--)
 		resizeColumnToContents(i);
 }
+
+#include "keytreeview.moc"
