@@ -111,7 +111,8 @@ KGpgTextInterfacePrivate::gpgPassphrase()
 	if (m_anonymous)
 		passdlgmessage = i18n("<p><b>No user id found</b>. Trying all secret keys.</p>");
 	if ((m_step < 3) && !m_anonymous)
-		passdlgmessage = i18n("<p><b>Bad passphrase</b>. You have %1 tries left.</p>", m_step);
+		passdlgmessage = i18np("<p><b>Bad passphrase</b>. You have 1 try left.</p>",
+		                       "<p><b>Bad passphrase</b>. You have %1 tries left.</p>", m_step);
 	if (m_userIDs.isEmpty())
 		passdlgmessage += i18n("Enter passphrase");
 	else
@@ -264,6 +265,10 @@ KGpgTextInterface::decryptTextStdOut()
 				d->m_textlength = line.mid(line.indexOf("PLAINTEXT_LENGTH") + 16).toInt();
 			} else if (line.startsWith("DECRYPTION_OKAY")) {
 				d->m_ok = true;
+				// this happens if the encrypted text does not end with '\n'
+				// 25 is strlen('[GNUPG:] DECRYPTION_OKAY')
+				if (d->m_tmpmessage.endsWith("[GNUPG:] DECRYPTION_OKAY\n"))
+					d->m_tmpmessage.chop(25);
 			} else if (line.startsWith("BADMDC")) {
 				d->m_badmdc = true;
 			} else if (line.startsWith("BAD_PASSPHRASE")) {
