@@ -27,6 +27,7 @@
 #include <QDomElement>
 #include <QDomNode>
 #include <QDomDocument>
+#include <QXmlStreamWriter>
 #include <kaction.h>
 #include <kdebug.h>
 #include <kdialog.h>
@@ -69,6 +70,8 @@ KWalletEditor::KWalletEditor(const QString& wallet, bool isPath, QWidget *parent
 	setObjectName(name);
 	_newWallet = false;
 	_ww = new WalletWidget(this);
+	_ww->_splitter->setStretchFactor(0, 1);
+	_ww->_splitter->setStretchFactor(1, 2);
 	_contextMenu = new KMenu(this);
 
 	QVBoxLayout *box = new QVBoxLayout(_ww->_entryListFrame);
@@ -88,8 +91,17 @@ KWalletEditor::KWalletEditor(const QString& wallet, bool isPath, QWidget *parent
 	box->addWidget(_mapEditor);
 
 	setCentralWidget(_ww);
+	setAutoSaveSettings(QLatin1String("WalletEditor"), true);
 
-	resize(600, 400);
+	// load splitter size
+	KConfigGroup cg(KGlobal::config(), "WalletEditor");
+	QList<int> splitterSize = cg.readEntry("SplitterSize", QList<int>());
+	if (splitterSize.size() != 2) {
+		splitterSize.clear();
+		splitterSize.append(_ww->_splitter->width()/2);
+		splitterSize.append(_ww->_splitter->width()/2);
+	}
+	_ww->_splitter->setSizes(splitterSize);
 
 	connect(_entryList, SIGNAL(selectionChanged(Q3ListViewItem*)),
 		this, SLOT(entrySelectionChanged(Q3ListViewItem*)));
@@ -135,11 +147,14 @@ KWalletEditor::KWalletEditor(const QString& wallet, bool isPath, QWidget *parent
 	delete toolBar();
 
 	setCaption(wallet);
-
-	QTimer::singleShot(0, this, SLOT(layout()));
 }
 
 KWalletEditor::~KWalletEditor() {
+	// save splitter size
+	KConfigGroup cg(KGlobal::config(), "WalletEditor");
+	cg.writeEntry("SplitterSize", _ww->_splitter->sizes());
+	cg.sync();
+	
 	emit editorClosed(this);
 	delete _newFolderAction;
 	_newFolderAction = 0L;
@@ -152,14 +167,6 @@ KWalletEditor::~KWalletEditor() {
 	}
 }
 
-void KWalletEditor::layout() {
-	QList<int> sz = _ww->_splitter->sizes();
-	int sum = sz[0] + sz[1];
-	sz[0] = sum/2;
-	sz[1] = sum/2;
-	_ww->_splitter->setSizes(sz);
-}
-
 void KWalletEditor::createActions() {
         _newFolderAction = actionCollection()->addAction( "create_folder" );
         _newFolderAction->setText( i18n("&New Folder...") );
@@ -366,7 +373,6 @@ void KWalletEditor::createFolder() {
 	}
 }
 
-
 void KWalletEditor::saveEntry() {
 	int rc = 1;
 	Q3ListViewItem *item = _entryList->currentItem();
@@ -1084,12 +1090,16 @@ void KWalletEditor::importXML() {
 void KWalletEditor::exportXML() {
 	KTemporaryFile tf;
 	tf.open();
-	QTextStream ts(&tf);
+	QXmlStreamWriter xml(&tf);
+	xml.setAutoFormatting(true);
+	xml.writeStartDocument();
 	const QStringList fl = _w->folderList();
 
-	ts << "<wallet name=\"" << _walletName << "\">" << endl;
+	xml.writeStartElement("wallet");
+	xml.writeAttribute("name", _walletName);
 	for (QStringList::const_iterator i = fl.constBegin(); i != fl.constEnd(); ++i) {
-		ts << "  <folder name=\"" << *i << "\">" << endl;
+		xml.writeStartElement("folder");
+		xml.writeAttribute("name", *i);
 		_w->setFolder(*i);
 		QStringList entries = _w->entryList();
 		for (QStringList::const_iterator j = entries.constBegin(); j != entries.constEnd(); ++j) {
@@ -1098,9 +1108,10 @@ void KWalletEditor::exportXML() {
 					{
 						QString pass;
 						if (_w->readPassword(*j, pass) == 0) {
-							ts << "    <password name=\"" << Qt::escape(*j) << "\">";
-							ts << Qt::escape(pass);
-							ts << "</password>" << endl;
+							xml.writeStartElement("password");
+							xml.writeAttribute("name", *j);
+							xml.writeCharacters(pass);
+							xml.writeEndElement();
 						}
 						break;
 					}
@@ -1108,10 +1119,10 @@ void KWalletEditor::exportXML() {
 					{
 						QByteArray ba;
 						if (_w->readEntry(*j, ba) == 0) {
-							ts << "    <stream name=\"" << Qt::escape(*j) << "\">";
-							ts << KCodecs::base64Encode(ba);
-
-							ts << "</stream>" << endl;
+							xml.writeStartElement("stream");
+							xml.writeAttribute("name", *j);
+							xml.writeCharacters(KCodecs::base64Encode(ba));
+							xml.writeEndElement();
 						}
 						break;
 					}
@@ -1119,11 +1130,15 @@ void KWalletEditor::exportXML() {
 					{
 						QMap<QString,QString> map;
 						if (_w->readMap(*j, map) == 0) {
-							ts << "    <map name=\"" << Qt::escape(*j) << "\">" << endl;
+							xml.writeStartElement("map");
+							xml.writeAttribute("name", *j);
 							for (QMap<QString,QString>::ConstIterator k = map.constBegin(); k != map.constEnd(); ++k) {
-								ts << "      <mapentry name=\"" << Qt::escape(k.key()) << "\">" << Qt::escape(k.value()) << "</mapentry>" << endl;
+								xml.writeStartElement("mapentry");
+								xml.writeAttribute("name", k.key());
+								xml.writeCharacters(k.value());
+								xml.writeEndElement();
 							}
-							ts << "    </map>" << endl;
+							xml.writeEndElement();
 						}
 						break;
 					}
@@ -1132,11 +1147,12 @@ void KWalletEditor::exportXML() {
 					break;
 			}
 		}
-		ts << "  </folder>" << endl;
+		xml.writeEndElement();
 	}
 
-	ts << "</wallet>" << endl;
-	ts.flush();
+	xml.writeEndElement();
+	xml.writeEndDocument();
+	tf.flush();
 
 	KUrl url = KFileDialog::getSaveUrl(KUrl(), "*.xml", this);
 
