@@ -263,9 +263,11 @@ void PieceTableByteArrayModel::Private::revertToVersionByIndex( int versionIndex
 
 void PieceTableByteArrayModel::Private::openGroupedChange( const QString &description )
 {
+    const bool isModifiedBefore = isModified();
     mBeforeGroupedChangeVersionIndex = mPieceTable.appliedChangesCount();
     mPieceTable.openGroupedChange( description );
 
+    if( ! isModifiedBefore ) emit p->modificationChanged( true );
     emit p->headVersionChanged( mPieceTable.changesCount() );
 }
 
