@@ -673,7 +673,7 @@ void AbstractByteArrayViewPrivate::paste()
 
 void AbstractByteArrayViewPrivate::pasteData( const QMimeData* data )
 {
-    if( !data )
+    if( ! data || data->formats().isEmpty() )
         return;
 
     // if there is a octet stream, use it, otherwise take the dump of the format
@@ -838,7 +838,15 @@ bool AbstractByteArrayViewPrivate::event( QEvent* event )
                 return true;
         }
     }
-    else if( event->type() == QEvent::ToolTip )
+
+    return q->ColumnsView::event( event );
+}
+
+bool AbstractByteArrayViewPrivate::viewportEvent( QEvent* event )
+{
+    Q_Q( AbstractByteArrayView );
+
+    if( event->type() == QEvent::ToolTip )
     {
         QHelpEvent* helpEvent = static_cast<QHelpEvent*>( event );
 
@@ -847,7 +855,7 @@ bool AbstractByteArrayViewPrivate::event( QEvent* event )
         KHECore::Bookmarkable* bookmarks = qobject_cast<KHECore::Bookmarkable*>( mByteArrayModel );
         if( bookmarks )
         {
-            const int index = indexByPoint( helpEvent->pos() );
+            const int index = indexByPoint( q->viewportToColumns(helpEvent->pos()) );
             if( index != -1 )
             {
                 if( bookmarks->containsBookmarkFor(index) )
@@ -866,7 +874,7 @@ bool AbstractByteArrayViewPrivate::event( QEvent* event )
         return true;
      }
 
-    return q->ColumnsView::event( event );
+    return q->ColumnsView::viewportEvent( event );
 }
 
 void AbstractByteArrayViewPrivate::resizeEvent( QResizeEvent* resizeEvent )
