@@ -27,11 +27,11 @@
 // KDE
 #include <KComboBox>
 #include <KLineEdit>
-#include <KDialog>
 // Qt
 #include <QtGui/QLayout>
+#include <QtGui/QAbstractItemView>
 
-
+#include <KDebug>
 class KByteArrayLineEditPrivate
 {
   public:
@@ -51,7 +51,6 @@ class KByteArrayLineEditPrivate
 void KByteArrayLineEditPrivate::setup( KByteArrayLineEdit *widget )
 {
     QVBoxLayout *baseLayout = new QVBoxLayout( widget );
-    baseLayout->setSpacing( KDialog::spacingHint() );
     baseLayout->setMargin( 0 );
 
     mFormatComboBox = new KComboBox( widget );
@@ -61,6 +60,12 @@ void KByteArrayLineEditPrivate::setup( KByteArrayLineEdit *widget )
     mDataEdit = new KLineEdit( widget );
     widget->setFocusProxy( mDataEdit );
     widget->connect( mDataEdit, SIGNAL(textChanged(const QString&)), SLOT(onDataChanged(const QString&)) );
+    QAbstractItemView* formatComboBoxListView = mFormatComboBox->view();
+    QObject::connect( formatComboBoxListView, SIGNAL(activated( const QModelIndex& )),
+             mDataEdit, SLOT(setFocus()) );
+    // TODO: is a workaround for Qt 4.5.1 which doesn't emit activated() for mouse clicks
+    QObject::connect( formatComboBoxListView, SIGNAL(pressed( const QModelIndex& )),
+             mDataEdit, SLOT(setFocus()) );
     mValidator = new KByteArrayValidator( mDataEdit );
     mDataEdit->setValidator( mValidator );
 
@@ -137,5 +142,3 @@ void KByteArrayLineEdit::onDataChanged( const QString &data )
 }
 
 KByteArrayLineEdit::~KByteArrayLineEdit() { delete d; }
-
-#include "kbytearraylineedit.moc"
