@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Kakao module, part of the KDE project.
 
-    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>
+    Copyright 2008-2009 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -37,7 +37,11 @@ OverwriteModeController::OverwriteModeController( KXMLGUIClient* guiClient )
     KActionCollection* actionCollection = guiClient->actionCollection();
 
     mSetOverWriteAction = actionCollection->add<KToggleAction>( "set_overwrite" );
-    mSetOverWriteAction->setText( i18nc("@option:check","Overwrite Mode") );
+    const QString text = i18nc( "@option:check set the view into overwrite mode", "Set Overwrite Mode" );
+    mSetOverWriteAction->setText( text );
+    const QString checkedText = i18nc( "@option:check set the view into insert mode", "Set Insert Mode" );
+    const KGuiItem checkedState( checkedText );
+    mSetOverWriteAction->setCheckedState( checkedState );
     mSetOverWriteAction->setWhatsThis(
         i18nc("@info:whatsthis",
               "Choose whether you want the input to be inserted or to overwrite existing data.") );
@@ -50,7 +54,7 @@ OverwriteModeController::OverwriteModeController( KXMLGUIClient* guiClient )
 
 void OverwriteModeController::setTargetModel( AbstractModel* model )
 {
-//     if( mByteArrayDisplay ) mByteArrayDisplay->disconnect( mSetOverWriteAction );
+    if( mByteArrayDisplay ) mByteArrayDisplay->disconnect( mSetOverWriteAction );
 
     mByteArrayDisplay = model ? model->findBaseModel<KByteArrayDisplay*>() : 0;
 
@@ -58,8 +62,8 @@ void OverwriteModeController::setTargetModel( AbstractModel* model )
     {
         mSetOverWriteAction->setChecked( mByteArrayDisplay->isOverwriteMode() );
 
-//         connect( mByteArrayDisplay, SIGNAL(overwriteModeChanged( bool )),
-//                  mSetOverWriteAction, SLOT(setChecked( bool )) );
+        connect( mByteArrayDisplay, SIGNAL(overwriteModeChanged( bool )),
+                 mSetOverWriteAction, SLOT(setChecked( bool )) );
         // TODO: catch if isOverwriteOnly changes
     }
 
