@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Kakao module, part of the KDE project.
 
-    Copyright 2006-2007 Friedrich W. H. Kossebau <kossebau@kde.org>
+    Copyright 2006-2007,2009 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -23,14 +23,29 @@
 #ifndef KREPLACEPROMPT_H
 #define KREPLACEPROMPT_H
 
+// controller
+#include "replaceuserqueryable.h"
 // KDE
 #include <KDialog>
 
+class QEventLoop;
+
 
 class KReplacePrompt : public KDialog
 {
   public:
-    KReplacePrompt( QWidget *parent );
+    explicit KReplacePrompt( QWidget* parent );
+
+  public:
+    KDE::ReplaceBehaviour query();
+
+  public: // KDialog API
+    virtual void slotButtonClicked( int button );
+
+  protected:
+    QEventLoop* mEventLoop;
+
+    KDE::ReplaceBehaviour mResult;
 };
 
 #endif
